@@ -47,6 +47,21 @@ func TestAnalyzePath(t *testing.T) {
 	assert.Nil(t, err)
 }
 
+func TestSequentialScanning(t *testing.T) {
+	fin := testdir.CreateTestDir()
+	defer fin()
+
+	out, err := runApp(
+		&Flags{LogFile: "/dev/null", SequentialScanning: true},
+		[]string{"test_dir"},
+		false,
+		testdev.DevicesInfoGetterMock{},
+	)
+
+	assert.Contains(t, out, "nested")
+	assert.Nil(t, err)
+}
+
 func TestFollowSymlinks(t *testing.T) {
 	fin := testdir.CreateTestDir()
 	defer fin()
@@ -62,6 +77,21 @@ func TestFollowSymlinks(t *testing.T) {
 	assert.Nil(t, err)
 }
 
+func TestShowAnnexedSize(t *testing.T) {
+	fin := testdir.CreateTestDir()
+	defer fin()
+
+	out, err := runApp(
+		&Flags{LogFile: "/dev/null", ShowAnnexedSize: true},
+		[]string{"test_dir"},
+		false,
+		testdev.DevicesInfoGetterMock{},
+	)
+
+	assert.Contains(t, out, "nested")
+	assert.Nil(t, err)
+}
+
 func TestAnalyzePathProfiling(t *testing.T) {
 	fin := testdir.CreateTestDir()
 	defer fin()
@@ -149,6 +179,66 @@ func TestAnalyzePathWithGui(t *testing.T) {
 	assert.Nil(t, err)
 }
 
+func TestAnalyzePathWithGuiNoColor(t *testing.T) {
+	fin := testdir.CreateTestDir()
+	defer fin()
+
+	out, err := runApp(
+		&Flags{LogFile: "/dev/null", NoColor: true},
+		[]string{"test_dir"},
+		true,
+		testdev.DevicesInfoGetterMock{},
+	)
+
+	assert.Empty(t, out)
+	assert.Nil(t, err)
+}
+
+func TestGuiShowMTimeAndItemCount(t *testing.T) {
+	fin := testdir.CreateTestDir()
+	defer fin()
+
+	out, err := runApp(
+		&Flags{LogFile: "/dev/null", ShowItemCount: true, ShowMTime: true},
+		[]string{"test_dir"},
+		true,
+		testdev.DevicesInfoGetterMock{},
+	)
+
+	assert.Empty(t, out)
+	assert.Nil(t, err)
+}
+
+func TestGuiNoDelete(t *testing.T) {
+	fin := testdir.CreateTestDir()
+	defer fin()
+
+	out, err := runApp(
+		&Flags{LogFile: "/dev/null", NoDelete: true},
+		[]string{"test_dir"},
+		true,
+		testdev.DevicesInfoGetterMock{},
+	)
+
+	assert.Empty(t, out)
+	assert.Nil(t, err)
+}
+
+func TestGuiDeleteInParallel(t *testing.T) {
+	fin := testdir.CreateTestDir()
+	defer fin()
+
+	out, err := runApp(
+		&Flags{LogFile: "/dev/null", DeleteInParallel: true},
+		[]string{"test_dir"},
+		true,
+		testdev.DevicesInfoGetterMock{},
+	)
+
+	assert.Empty(t, out)
+	assert.Nil(t, err)
+}
+
 func TestAnalyzePathWithGuiBackgroundDeletion(t *testing.T) {
 	fin := testdir.CreateTestDir()
 	defer fin()
@@ -200,6 +290,20 @@ func TestAnalyzePathWithStyle(t *testing.T) {
 				ProgressModal: ProgressModalOpts{
 					CurrentItemNameMaxLen: 10,
 				},
+				Footer: FooterColorStyle{
+					TextColor:       "black",
+					BackgroundColor: "red",
+					NumberColor:     "white",
+				},
+				Header: HeaderColorStyle{
+					TextColor:       "black",
+					BackgroundColor: "red",
+					Hidden:          true,
+				},
+				ResultRow: ResultRowColorStyle{
+					NumberColor:    "orange",
+					DirectoryColor: "blue",
+				},
 				UseOldSizeBar: true,
 			},
 		},
@@ -212,6 +316,24 @@ func TestAnalyzePathWithStyle(t *testing.T) {
 	assert.Nil(t, err)
 }
 
+func TestAnalyzePathNoUnicode(t *testing.T) {
+	fin := testdir.CreateTestDir()
+	defer fin()
+
+	out, err := runApp(
+		&Flags{
+			LogFile:   "/dev/null",
+			NoUnicode: true,
+		},
+		[]string{"test_dir"},
+		false,
+		testdev.DevicesInfoGetterMock{},
+	)
+
+	assert.Contains(t, out, "nested")
+	assert.Nil(t, err)
+}
+
 func TestAnalyzePathWithExport(t *testing.T) {
 	fin := testdir.CreateTestDir()
 	defer fin()
@@ -425,6 +547,7 @@ func TestMaxCoresLowEdge(t *testing.T) {
 	assert.Nil(t, err)
 }
 
+// nolint: unparam // Why: it's used in linux tests
 func runApp(flags *Flags, args []string, istty bool, getter device.DevicesInfoGetter) (string, error) {
 	buff := bytes.NewBufferString("")
 
