@@ -1,7 +1,6 @@
 package tui
 
 import (
-	"bufio"
 	"bytes"
 	"fmt"
 	"io"
@@ -13,17 +12,26 @@ import (
 	"strings"
 	"time"
 
+	"github.com/gdamore/tcell/v2"
+	"github.com/rivo/tview"
+
 	"github.com/dundee/gdu/v5/build"
 	"github.com/dundee/gdu/v5/pkg/analyze"
 	"github.com/dundee/gdu/v5/pkg/device"
 	"github.com/dundee/gdu/v5/pkg/fs"
 	"github.com/dundee/gdu/v5/report"
-	"github.com/gdamore/tcell/v2"
-	"github.com/rivo/tview"
 )
 
-const defaultLinesCount = 500
-const linesTreshold = 20
+const (
+	defaultLinesCount = 500
+	linesThreshold    = 20
+
+	actionEmpty  = "empty"
+	actionDelete = "delete"
+
+	actingEmpty  = "emptying"
+	actingDelete = "deleting"
+)
 
 // ListDevices lists mounted devices and shows their disk usage
 func (ui *UI) ListDevices(getter device.DevicesInfoGetter) error {
@@ -176,11 +184,11 @@ func (ui *UI) deleteSelected(shouldEmpty bool) {
 
 	var action, acting string
 	if shouldEmpty {
-		action = "empty "
-		acting = "emptying"
+		action = actionEmpty
+		acting = actingEmpty
 	} else {
-		action = "delete "
-		acting = "deleting"
+		action = actionDelete
+		acting = actingDelete
 	}
 	modal := tview.NewModal().SetText(
 		// nolint: staticcheck // Why: fixed string
@@ -212,7 +220,7 @@ func (ui *UI) deleteSelected(shouldEmpty bool) {
 	go func() {
 		for _, item := range deleteItems {
 			if err := deleteFun(currentDir, item); err != nil {
-				msg := "Can't " + action + tview.Escape(selectedItem.GetName())
+				msg := "Can't " + action + " " + tview.Escape(selectedItem.GetName())
 				ui.app.QueueUpdateDraw(func() {
 					ui.pages.RemovePage(acting)
 					ui.showErr(msg, err)
@@ -238,95 +246,6 @@ func (ui *UI) deleteSelected(shouldEmpty bool) {
 	}()
 }
 
-func (ui *UI) showFile() *tview.TextView {
-	if ui.currentDir == nil {
-		return nil
-	}
-
-	row, column := ui.table.GetSelection()
-	selectedFile := ui.table.GetCell(row, column).GetReference().(fs.Item)
-	if selectedFile.IsDir() {
-		return nil
-	}
-
-	f, err := os.Open(selectedFile.GetPath())
-	if err != nil {
-		ui.showErr("Error opening file", err)
-		return nil
-	}
-
-	totalLines := 0
-	scanner := bufio.NewScanner(f)
-
-	file := tview.NewTextView()
-	ui.currentDirLabel.SetText("[::b] --- " +
-		strings.TrimPrefix(selectedFile.GetPath(), build.RootPathPrefix) +
-		" ---").SetDynamicColors(true)
-
-	readNextPart := func(linesCount int) int {
-		var err error
-		readLines := 0
-		for scanner.Scan() && readLines <= linesCount {
-			_, err = file.Write(scanner.Bytes())
-			if err != nil {
-				ui.showErr("Error reading file", err)
-				return 0
-			}
-			_, err = file.Write([]byte("\n"))
-			if err != nil {
-				ui.showErr("Error reading file", err)
-				return 0
-			}
-			readLines++
-		}
-		return readLines
-	}
-	totalLines += readNextPart(defaultLinesCount)
-
-	file.SetInputCapture(func(event *tcell.EventKey) *tcell.EventKey {
-		if event.Rune() == 'q' || event.Key() == tcell.KeyESC {
-			err = f.Close()
-			if err != nil {
-				ui.showErr("Error closing file", err)
-				return event
-			}
-			ui.currentDirLabel.SetText("[::b] --- " +
-				strings.TrimPrefix(ui.currentDirPath, build.RootPathPrefix) +
-				" ---").SetDynamicColors(true)
-			ui.pages.RemovePage("file")
-			ui.app.SetFocus(ui.table)
-			return event
-		}
-
-		switch {
-		case event.Rune() == 'j':
-			fallthrough
-		case event.Rune() == 'G':
-			fallthrough
-		case event.Key() == tcell.KeyDown:
-			fallthrough
-		case event.Key() == tcell.KeyPgDn:
-			_, _, _, height := file.GetInnerRect()
-			row, _ := file.GetScrollOffset()
-			if height+row > totalLines-linesTreshold {
-				totalLines += readNextPart(defaultLinesCount)
-			}
-		}
-		return event
-	})
-
-	grid := tview.NewGrid().SetRows(1, 1, 0, 1).SetColumns(0)
-	grid.AddItem(ui.header, 0, 0, 1, 1, 0, 0, false).
-		AddItem(ui.currentDirLabel, 1, 0, 1, 1, 0, 0, false).
-		AddItem(file, 2, 0, 1, 1, 0, 0, true).
-		AddItem(ui.footerLabel, 3, 0, 1, 1, 0, 0, false)
-
-	ui.pages.HidePage("background")
-	ui.pages.AddPage("file", grid, true, true)
-
-	return file
-}
-
 func (ui *UI) showInfo() {
 	if ui.currentDir == nil {
 		return
@@ -337,9 +256,12 @@ func (ui *UI) showInfo() {
 	selectedFile := ui.table.GetCell(row, column).GetReference().(fs.Item)
 
 	if ui.UseColors {
-		numberColor = "[#e67100::b]"
+		numberColor = fmt.Sprintf(
+			"[%s::b]",
+			ui.resultRow.NumberColor,
+		)
 	} else {
-		numberColor = "[::b]"
+		numberColor = defaultColorBold
 	}
 
 	linesCount := 12
@@ -474,11 +396,11 @@ func (ui *UI) exportAnalysis() {
 		}
 
 		if _, err = buff.Write([]byte("]\n")); err != nil {
-			ui.showErrFromGo("Error writting to buffer", err)
+			ui.showErrFromGo("Error writing to buffer", err)
 			return
 		}
 		if _, err = buff.WriteTo(file); err != nil {
-			ui.showErrFromGo("Error writting to file", err)
+			ui.showErrFromGo("Error writing to file", err)
 			return
 		}
 	}()
